@@ -2,20 +2,14 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Notes",
-    "New note" : "New note",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "There are unsaved notes. Leaving the page will discard all changes!",
-    "_%n word_::_%n words_" : ["%n word","%n words"],
     "The last viewed note cannot be accessed. " : "The last viewed note cannot be accessed. ",
-    "File error" : "File error",
     "Encryption Error" : "Encryption Error",
     "Error" : "Error",
+    "New note" : "New note",
     "Distraction-free notes and writing" : "Distraction-free notes and writing",
-    "No notes found" : "No notes found",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "There are unsaved notes. Leaving the page will discard all changes!",
     "Delete note" : "Delete note",
-    "Favorite" : "Favourite",
-    "The note has unsaved changes." : "The note has unsaved changes.",
-    "Click here to try again" : "Click here to try again",
     "Saving failed!" : "Saving failed!",
-    "Note saved" : "Note saved"
+    "_%n word_::_%n words_" : ["%n word","%n words"]
 },
 "nplurals=2; plural=(n != 1);");
