@@ -3,9 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Notas",
     "New note" : "Nueva nota",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
     "Delete note" : "Borrar nota",
-    "Favorite" : "Favorito",
-    "No notes found" : "No se encontraron notas"
+    "_%n word_::_%n words_" : ["%n palabra","%n palabras"]
 },
 "nplurals=2; plural=(n != 1);");
