@@ -3,9 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Notes",
     "New note" : "Nova bilješka",
-    "_%n word_::_%n words_" : ["%n riječ","%n riječi","%n riječi"],
     "Delete note" : "Obriši bilješku",
-    "Favorite" : "Omiljena",
-    "No notes found" : "Nije pronađena nijedna bilješka"
+    "_%n word_::_%n words_" : ["%n riječ","%n riječi","%n riječi"]
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
