@@ -1,16 +1,17 @@
 OC.L10N.register(
     "notes",
     {
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
-    "Please wait while new settings are applied…" : "Palaukite, kol yra taikomi nauji nustatymai…",
-    "File error" : "Failo klaida",
     "Encryption Error" : "Šifravimo klaida",
     "Error" : "Klaida",
-    "Favorite" : "Svarbiausias",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
     "Settings" : "Nustatymai",
-    "The note has unsaved changes." : "Užrašuose yra neįrašytų pakeitimų.",
-    "Click here to try again" : "Spustelėkite čia, norėdami bandyti dar kartą",
+    "Categories" : "Kategorijos",
+    "Yesterday" : "Vakar",
+    "Preview" : "Peržiūra",
+    "Fullscreen" : "Visas ekranas",
+    "Save failed. Click to retry." : "Nepavyko įrašyti. Spustelėkite, norėdami bandyti dar kartą.",
     "Saving failed!" : "Įrašymas nepavyko!",
-    "Note saved" : "Užrašai įrašyti"
+    "Android app" : "Android programėlė",
+    "iOS app" : "iOS programėlė"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
