@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Белешки",
     "New note" : "Нова белешка",
-    "_%n word_::_%n words_" : ["%n збор","%n зборови"],
-    "Delete note" : "Избриши белешка"
+    "Delete note" : "Избриши белешка",
+    "_%n word_::_%n words_" : ["%n збор","%n зборови"]
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
