@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Nòtas",
     "New note" : "Nòta novèla",
-    "_%n word_::_%n words_" : ["%n mot","%n mots"],
-    "Delete note" : "Suprimir la nòta"
+    "Delete note" : "Suprimir la nòta",
+    "_%n word_::_%n words_" : ["%n mot","%n mots"]
 },
 "nplurals=2; plural=(n > 1);");
