@@ -3,9 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Note",
     "New note" : "Notă nouă",
-    "_%n word_::_%n words_" : ["%n cuvânt","%n cuvinte","%n cuvinte"],
     "Delete note" : "Şterge nota",
-    "Favorite" : "Favorite",
-    "No notes found" : "Nu s-au găsit note"
+    "_%n word_::_%n words_" : ["%n cuvânt","%n cuvinte","%n cuvinte"]
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
